package main

import (
	"database/sql"
	migration "bitbucket.org/prmunty/util/dbmigration/db"
	_ "github.com/mattn/go-sqlite3"
	"bitbucket.org/prmunty/util/logger"
)

func main() {
	const version float64 = 3.0
	logger.Log.Printf("Started Database Migration for Version:", version)
	migration.Migrate(version, func(tx *sql.Tx) (err error) {
		return migration.DoUntilErr(tx,
			RemoveFreezeData,
			AddFreezeData,
		)
	})
}

func RemoveFreezeData(tx *sql.Tx) error {
	freeze_ids := []int{2246,2247,2248,2249}

	for _, freeze_id := range freeze_ids {
		logger.Log.Printf("DELETING Freeze Data WHERE freeze_id=", freeze_id)
		if _, err := tx.Exec(
			`DELETE FROM freeze_data_acuair WHERE freeze_id=?`,
			freeze_id,
		); err != nil {
			logger.Log.Printf("ERROR!!! ", err)
			return err
		}
	}

	return nil
}




func AddFreezeData(tx *sql.Tx) error {
	freeze_ids := []int{2239,2505,2228}
	mode_ordinals := []int{62,63,64}

	for i, freeze_id := range freeze_ids {

		if _, err := tx.Exec(
			`INSERT OR IGNORE INTO freeze_data_acuair(freeze_id, table_id, selected, ordinal) VALUES(?,0,1,?)`,
			freeze_id, mode_ordinals[i],
		); err != nil {
			logger.Log.Printf("ERROR!!! ", err)
			return err
		}
	}

	return nil
}